# eric7.Plugins.VcsPlugins.vcsGit.ConfigurationPage.GitPage

Module implementing the Git configuration page.

### Global Attributes

None

### Classes

GitPage | Class implementing the Git configuration page.

### Functions

None

## GitPage

Class implementing the Git configuration page.

### Derived from

ConfigurationPageBase, Ui_GitPage

### Class Attributes

None

### Class Methods

None

### Methods

GitPage | Constructor
on_configButton_clicked | Private slot to edit the (per user) Git configuration file.
save | Public slot to save the Git configuration.

### Static Methods

None

#### GitPage (Constructor)

GitPage(plugin)

Constructor

plugin (VcsGitPlugin)
  reference to the plugin object

#### GitPage.on_configButton_clicked

on_configButton_clicked()

Private slot to edit the (per user) Git configuration file.

#### GitPage.save

save()

Public slot to save the Git configuration.

Up